@@ -1,5 +1,6 @@
 //! Main SVG document structure.
 
+use data_url::mime::Mime;
 use gdk_pixbuf::{PixbufLoader, PixbufLoaderExt};
 use markup5ever::QualName;
 use once_cell::sync::Lazy;
@@ -8,6 +9,7 @@ use std::collections::hash_map::Entry;
 use std::collections::HashMap;
 use std::include_str;
 use std::rc::Rc;
+use std::str::FromStr;
 
 use crate::allowed_url::{AllowedUrl, AllowedUrlError, Fragment};
 use crate::attributes::Attributes;
@@ -194,21 +196,14 @@ fn load_image(
 ) -> Result<SharedImageSurface, LoadingError> {
     let BinaryData {
         data: bytes,
-        mut content_type,
+        mime_type,
     } = io::acquire_data(&aurl, None)?;
 
     if bytes.is_empty() {
         return Err(LoadingError::EmptyData);
     }
 
-    // See issue #548 - data: URLs without a MIME-type automatically
-    // fall back to "text/plain;charset=US-ASCII".  Some (old?) versions of
-    // Adobe Illustrator generate data: URLs without MIME-type for image
-    // data.  We'll catch this and fall back to sniffing by unsetting the
-    // content_type.
-    if content_type.as_deref() == Some("text/plain;charset=US-ASCII") {
-        content_type = None;
-    }
+    let content_type = content_type_for_gdk_pixbuf(&mime_type);
 
     let loader = if let Some(ref content_type) = content_type {
         PixbufLoader::new_with_mime_type(content_type)?
@@ -232,6 +227,21 @@ fn load_image(
     Ok(surface)
 }
 
+fn content_type_for_gdk_pixbuf(mime_type: &Mime) -> Option<String> {
+    // See issue #548 - data: URLs without a MIME-type automatically
+    // fall back to "text/plain;charset=US-ASCII".  Some (old?) versions of
+    // Adobe Illustrator generate data: URLs without MIME-type for image
+    // data.  We'll catch this and fall back to sniffing by unsetting the
+    // content_type.
+    let unspecified_mime_type = Mime::from_str("text/plain;charset=US-ASCII").unwrap();
+
+    if *mime_type == unspecified_mime_type {
+        None
+    } else {
+        Some(format!("{}/{}", mime_type.type_, mime_type.subtype))
+    }
+}
+
 pub struct AcquiredNode {
     stack: Option<Rc<RefCell<NodeStack>>>,
     node: Node,
@@ -479,3 +489,25 @@ impl DocumentBuilder {
         }
     }
 }
+
+#[cfg(test)]
+mod tests {
+    use super::*;
+
+    #[test]
+    fn unspecified_mime_type_yields_no_content_type() {
+        // Issue #548
+        let mime = Mime::from_str("text/plain;charset=US-ASCII").unwrap();
+        assert!(content_type_for_gdk_pixbuf(&mime).is_none());
+    }
+
+    #[test]
+    fn strips_mime_type_parameters() {
+        // Issue #699
+        let mime = Mime::from_str("image/png;charset=utf-8").unwrap();
+        assert_eq!(
+            content_type_for_gdk_pixbuf(&mime),
+            Some(String::from("image/png"))
+        );
+    }
+}
