@@ -106,7 +106,6 @@ pub struct ElementInner<T: SetAttributes + Draw> {
     transform: Transform,
     values: ComputedValues,
     cond: bool,
-    style_attr: String,
     pub element_impl: T,
 }
 
@@ -130,12 +129,9 @@ impl<T: SetAttributes + Draw> ElementInner<T> {
             transform: Default::default(),
             values: Default::default(),
             cond: true,
-            style_attr: String::new(),
             element_impl,
         };
 
-        e.save_style_attribute();
-
         let mut set_attributes = || -> Result<(), ElementError> {
             e.set_transform_attribute()?;
             e.set_conditional_processing_attributes()?;
@@ -186,16 +182,6 @@ impl<T: SetAttributes + Draw> ElementInner<T> {
         self.transform
     }
 
-    fn save_style_attribute(&mut self) {
-        self.style_attr.push_str(
-            self.attributes
-                .iter()
-                .find(|(attr, _)| attr.expanded() == expanded_name!("", "style"))
-                .map(|(_, value)| value)
-                .unwrap_or(""),
-        );
-    }
-
     fn set_transform_attribute(&mut self) -> Result<(), ElementError> {
         self.transform = self
             .attributes
@@ -273,19 +259,23 @@ impl<T: SetAttributes + Draw> ElementInner<T> {
         );
     }
 
-    /// Applies CSS styles from the saved value of the "style" attribute
+    /// Applies CSS styles from the "style" attribute
     fn set_style_attribute(&mut self) {
-        if !self.style_attr.is_empty() {
+        let style = self
+            .attributes
+            .iter()
+            .find(|(attr, _)| attr.expanded() == expanded_name!("", "style"))
+            .map(|(_, value)| value)
+            .unwrap_or("");
+
+        if !style.is_empty() {
             if let Err(e) = self.specified_values.parse_style_declarations(
-                self.style_attr.as_str(),
+                style,
                 Origin::Author,
                 &mut self.important_styles,
             ) {
                 self.set_error(e);
             }
-
-            self.style_attr.clear();
-            self.style_attr.shrink_to_fit();
         }
     }
 
