@@ -546,7 +546,11 @@ impl SpecifiedValues {
 
     pub fn to_computed_values(&self, computed: &mut ComputedValues) {
         macro_rules! compute {
-            ($name:ident, $field:ident) => {
+            ($name:ident, $field:ident) => {{
+                // This extra block --------^
+                // is so that prop_val will be dropped within the macro invocation;
+                // otherwise all the temporary values cause this function to use
+                // an unreasonably large amount of stack space.
                 let prop_val = self.get_property(PropertyId::$name);
                 if let ParsedProperty::$name(s) = prop_val {
                     computed.set_value(ComputedValue::$name(
@@ -555,7 +559,7 @@ impl SpecifiedValues {
                 } else {
                     unreachable!();
                 }
-            };
+            }};
         }
 
         // First, compute font_size.  It needs to be done before everything
